'use strict'
const DropBox = {};
const Joi = require ('joi');
const Boom = require ('boom')
const fs = require('fs-extra');
const config = require('dull-config');
const path = require ('path');

DropBox.register = (server, options, next)=>{

  server.route([
    {
      path : '/', method : 'GET',
      handler: (request, reply)=>{
        reply('5Inc DropBox');
      }
    },
    {
      path : '/drop', method : 'GET',
      config : {
        validate : {
          query : {
            fileName : Joi.string().required(),
            fileContents : Joi.string().required(),
            folder : Joi.string().required(),
          }
        }
      },
      handler: (request, reply)=>{
        let fileName = request.query.fileName;
        let data = request.query.fileContents;
        let folder = request.query.folder;
        let outPutFolder = config.get('dropbox.outputDirectory');

        fs.emptydirSync(path.join(outPutFolder, folder));

        //wait for 3 seconds before writing new file
        setTimeout(

          ()=>{
            let fullPath = path.join(outPutFolder, folder, fileName)
            fs.writeFile(fullPath, data, (err )=>{

              if(err){
                let msg = `couldn't save file. tried to write to ${err.path}`;

                console.log(msg)
                return reply(Boom.badRequest)
              }
              return reply({success:true});
            })

          },
          3000 // 3 seconds
        )

      }
    }
  ]);

  next()

};

DropBox.register.attributes = {
  name: 'DropBox',
  version: '0.1.0'
};

module.exports = DropBox;